Because of the d_count name change made in dcache.h, all references
to d_count have to be changed to d_refcount.  There is no change in
logic and everything should just work.

Signed-off-by: Waiman Long <[email protected]>
---
 fs/coda/dir.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/fs/coda/dir.c b/fs/coda/dir.c
index b7d3a05..4bf9574 100644
--- a/fs/coda/dir.c
+++ b/fs/coda/dir.c
@@ -560,7 +560,7 @@ static int coda_dentry_revalidate(struct dentry *de, 
unsigned int flags)
        if (cii->c_flags & C_FLUSH) 
                coda_flag_inode_children(inode, C_FLUSH);
 
-       if (de->d_count > 1)
+       if (de->d_refcount > 1)
                /* pretend it's valid, but don't change the flags */
                goto out;
 
@@ -575,7 +575,7 @@ out:
 }
 
 /*
  * This is the callback from dput() when d_count is going to 0.
  * We use this to unhash dentries with bad inodes.
  */
 static int coda_dentry_delete(const struct dentry * dentry)
@@ -575,7 +575,7 @@ out:
 
 /*
- * This is the callback from dput() when d_count is going to 0.
+ * This is the callback from dput() when d_refcount is going to 0.
  * We use this to unhash dentries with bad inodes.
  */
-- 
1.7.1

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to